@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tab-groups-extension.c 1376 2006-09-13 19:01:42Z chpe $
+ *  $Id: ephy-tab-groups-extension.c 1622 2007-11-03 21:57:34Z diegoe $
  */
 
 #include "config.h"
@@ -53,7 +53,7 @@ ephy_tab_groups_extension_register_type (GTypeModule *module)
 		(GClassInitFunc) ephy_tab_groups_extension_class_init,
 		NULL,
 		NULL, /* class_data */
-		sizeof (EphyTab),
+		sizeof (EphyTabGroupsExtension),
 		0,	/* n_preallocs */
 		(GInstanceInitFunc) ephy_tab_groups_extension_init
 	};
